# PyTemp
## A CLI tool for rendering python code using Jinja2
### Installation (Git)
```
git clone https://github.com/TeamNightSky/PyTemp
cd PyTemp
python setup.py install
```

### Installation (Pip) from [PyPI](https://pypi.org/project/pythontemplates)

```
pip install pythontemplates
```

### Usage
For help, use:
`pytemp --help`

## That's about it! ;)
